// ---------------------------------------------------------------------------
// keep_moving.cs -- Version 2.5 -- October 28, 2000
// by Lorne Laliberte (writer@planetstarsiege.com)
//
// Tap a movement key to keep moving in that direction
//
// http://www.writerscripts.com
// ---------------------------------------------------------------------------

include("writer\\version.cs");
version("writer\\keep_moving.cs", "2.5", "Lorne Laliberte", "Oct 28, 2000");

include("writer\\event.cs");
include("writer\\move.cs");
include("writer\\save.cs");
include("writer\\tap.cs");

// ---------------------------------------------------------------------------
// DEFAULT SETTINGS:
//
// Edit these if you're running this script for the first time
// All subsequent settings must be done in the config\wp_keep_moving.cs file

    // Enable keep moving mode by default
    $KeepMoving::Enabled = "false";

    // Automatically enable Keep Moving mode when entering Pilot Mode
    $Writer::EnableKeepMovingOnPilotMode = "true";

    // Toggle continuous movement on key tap for the 4 movement keys
    //bind(keyboard0, make, alt, "w", to, "KeepMoving::Toggle();");
    //bind(keyboard0, break, alt, "w", to, "", "KeepMoving::Toggle_break");

// ---------------------------------------------------------------------------

WriterPrefs::load("keep_moving");

function KeepMoving::onPilotModeOn()
{
    if($Writer::EnableKeepMovingOnPilotMode)
    {
        $KeepMoving::wasEnabled = $KeepMoving::Enabled;

        KeepMoving::Toggle(1, 1);
    }
    return;
}


function KeepMoving::onPilotModeOff()
{
    if(!$KeepMoving::wasEnabled)
        KeepMoving::Toggle(0, 1);

    return;
}




// Toggle continuous movement on key tap for the 4 movement keys
//
function KeepMoving::Toggle(%on, %quiet)
{
    if(%on == "")
    {
        // Toggle our flag
        $KeepMoving::Enabled = !$KeepMoving::Enabled;
    }
    else if(%on)
    {
        $KeepMoving::Enabled = true;
    }
    else
    {
        $KeepMoving::Enabled = false;
    }

    %text = "<f2>ENABLED<f0>"; // assume enabled; I just want to give %text scope outside the if blocks

    if($KeepMoving::Enabled) // we switched it on
    {
        Event::Attach(eventForwardPressed, "tap(moveforward, 0.06); postAction(2048, IDACTION_MOVEBACK, 0.0);");
        Event::Attach(eventForwardReleased, "if(wasTapped(moveforward)) return mute;");

        Event::Attach(eventBackPressed, "tap(moveback, 0.06); postAction(2048, IDACTION_MOVEFORWARD, 0.0);");
        Event::Attach(eventBackReleased, "if(wasTapped(moveback)) return mute;");

        Event::Attach(eventLeftPressed, "tap(moveleft, 0.06); postAction(2048, IDACTION_MOVERIGHT, 0.0);");
        Event::Attach(eventLeftReleased, "if(wasTapped(moveleft)) return mute;");

        Event::Attach(eventRightPressed, "tap(moveright, 0.06); postAction(2048, IDACTION_MOVELEFT, 0.0);");
        Event::Attach(eventRightReleased, "if(wasTapped(moveright)) return mute;");
    }
    else // we switched it off
    {
        EditActionMap("playMap.sae");

        Event::Detach(eventForwardPressed, "tap(moveforward, 0.06); postAction(2048, IDACTION_MOVEBACK, 0.0);");
        Event::Detach(eventForwardReleased, "if(wasTapped(moveforward)) return mute;");

        Event::Detach(eventBackPressed, "tap(moveback, 0.06); postAction(2048, IDACTION_MOVEFORWARD, 0.0);");
        Event::Detach(eventBackReleased, "if(wasTapped(moveback)) return mute;");

        Event::Detach(eventLeftPressed, "tap(moveleft, 0.06); postAction(2048, IDACTION_MOVERIGHT, 0.0);");
        Event::Detach(eventLeftReleased, "if(wasTapped(moveleft)) return mute;");

        Event::Detach(eventRightPressed, "tap(moveright, 0.06); postAction(2048, IDACTION_MOVELEFT, 0.0);");
        Event::Detach(eventRightReleased, "if(wasTapped(moveright)) return mute;");

        %text = "<f2>DISABLED<f0>";
    }

    if(!%quiet)
	    remoteBP(2048, " Keep Moving " @ %text, 4);
}

function keep_moving::save()
{
    AddExportText("    // Enable keep moving mode by default");
    ExportSetting("    $KeepMoving::Enabled", false);
    AddExportText("");
    AddExportText("    // Automatically enable Keep Moving mode when entering Pilot Mode");
    ExportSetting("    $Writer::EnableKeepMovingOnPilotMode", true);
    AddExportText("");
    AddExportText("    // Toggle continuous movement on key tap for the 4 movement keys");

    ExportBind("KeepMoving::Toggle();", "//bind(keyboard0, make, alt, \"w\", TO, \"KeepMoving::Toggle();\");");
    ExportBind("KeepMoving::Toggle_break", "//bind(keyboard0, break, alt, \"w\", TO, \"\", KeepMoving::Toggle_break);");
}

WriterPrefs::save("keep_moving");

function keep_moving::init()
{
    needs("writer\\keep_moving.cs", "writer\\event.cs 2.7",
                                    "writer\\move.cs 1.3",
                                    "writer\\save.cs 2.3",
                                    "writer\\tap.cs 1.2");

    Event::Attach(eventPilotModeOn, "KeepMoving::onPilotModeOn();");
    Event::Attach(eventPilotModeOff, "KeepMoving::onPilotModeOff();");
    Event::Attach(eventYouDied, "$KeepMoving::Enabled=$KeepMoving::wasEnabled;");
}
Event::Attach(writerInit, "keep_moving::init();");

if(!$UsingWriterLoader) keep_moving::init();
